@@ -38,6 +38,13 @@
 battery* battery_new() {
     static int battery_num = 1;
     battery * b = g_new0 ( battery, 1 );
+    battery_reset(b);
+    b->battery_num = battery_num;
+    battery_num++;
+    return b;
+}
+
+void battery_reset( battery * b) {
     b->type_battery = TRUE;
     b->capacity_unit = "mAh";
     b->last_capacity_unit = -1;
@@ -49,12 +56,8 @@ battery* battery_new() {
     b->remaining_capacity = -1;
     b->present_rate = -1;
     b->state = NULL;
-    b->battery_num = battery_num;
-    battery_num++;
-    return b;
 }
 
-
 static gchar* parse_info_file(char *filename)
 {
     char *buf = NULL;
@@ -136,6 +139,8 @@ void battery_update( battery *b ) {
     };
     const gchar *sys_file;
 
+    battery_reset(b);
+
     while ( (sys_file = sys_list[i]) != NULL ) {
     
 	gchar *file_content;
@@ -150,7 +155,7 @@ void battery_update( battery *b ) {
 		    b->state = "available";
 	    }
 	    else if ( strcmp("energy_now", sys_file ) == 0 ) {
-		b->remaining_capacity = get_unit_value((gchar*) file_content) / 1000;
+		b->remaining_energy = get_unit_value((gchar*) file_content) / 1000;
 		if (!b->state)
 		    b->state = "available";
 	    }
@@ -215,7 +220,7 @@ void battery_update( battery *b ) {
     if (b->last_capacity < MIN_CAPACITY)
 	b->percentage = 0;
     else
-	b->percentage = b->remaining_capacity * 100 / b->last_capacity;
+	b->percentage = ((float) b->remaining_energy * 100.0) / (float) b->last_capacity_unit;
 	    
     if (b->percentage > 100)
 	b->percentage = 100;
